<?php
/**
 * Tuned functions and definitions.
 *
 * @package      Tuned
 * @author       Elod Horvath
 * @copyright    2013-... Elod Horvath
 * @since        1.0
 */

 
 if ( ! isset( $content_width ) )
	$content_width = 900;
	
 
/* Tuned theme setup 
----------------------------------------------------------*/
function tuned_setup() {
	
	/* Add editor style */
	add_editor_style();
	
	/* Custom header */
	$args_ch = array( 
		// Header image default
	       'default-image'			=> get_template_directory_uri() . '/images/default-logo.png',
	        // Header text display default
	       'header-text'			=> false,
	        // Header image flex width
		   'flex-width'             => true,
	        // Header image width (in pixels)
	       'width'				    => 300,
		    // Header image flex height
		   'flex-height'            => true,
	        // Header image height (in pixels)
	       'height'			        => 100
	);
	add_theme_support( 'custom-header', $args_ch );
	
	/* Post thumbnails */
	add_theme_support( 'post-thumbnails' );
	//set_post_thumbnail_size( 624, 9999 );
	
	/* Make theme available for translation */
	load_theme_textdomain( 'tuned', get_template_directory() . '/languages' );
	
	/* Add Primary Navigation Menu */
	register_nav_menu( 'primary', __( 'Primary Menu', 'tuned' ) );
	
	/* Add posts and comments RSS feed links to <head> */
	add_theme_support( 'automatic-feed-links' );
	
	/* Add support for custom backgrounds. */
	$args_cb = array( 
		'default-color' => 'FFF',
		//'default-image' => ''
	);
	add_theme_support( 'custom-background', $args_cb );
	
	//require_once('inc/tuned_customizer.php');
    require_once('inc/tuned_customizer.php');
	
	add_theme_support( 'title-tag' );
	
	
}
add_action( 'after_setup_theme', 'tuned_setup' );



/* Add styles, and/or javascripts to theme 
-----------------------------------------------------------*/
function tuned_scripts() {
	
	// Add styles
	wp_enqueue_style( 'tuned-style', get_stylesheet_uri() );
	wp_enqueue_style( 'tuned-ie', get_template_directory_uri() .'/css/ie.css' );
	wp_enqueue_style( 'Montserrat', 'http://fonts.googleapis.com/css?family=Montserrat:400,700' );
	wp_enqueue_style( 'flexslider', get_template_directory_uri() .'/js/vendor/flexslider/flexslider.css' );
	
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() )
		wp_enqueue_script( 'comment-reply' );

    // Internet Explorer HTML5 support 
    wp_enqueue_script( 'html5shiv', get_template_directory_uri().'/js/vendor/html5shiv.js', array(), '', false);
    wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );
	
	// Add FlexSlider
	wp_enqueue_script( 'tuned_flexslider', get_template_directory_uri() .'/js/vendor/flexslider/jquery.flexslider.js', array( 'jquery' ) );
	
	// Add Infinite Scroll
	wp_enqueue_script( 'tuned_infinite_scroll', get_template_directory_uri() .'/js/vendor/infinite-scroll/jquery.infinitescroll.js', array( 'jquery' ) );
	
	// Add Masonry
    wp_enqueue_script( 'jquery-masonry' );
	
	// Add Tuned javascript file
	wp_enqueue_script( 'tuned_scripts', get_template_directory_uri() .'/js/tuned_scripts.js' );
	wp_localize_script( 'tuned_scripts', 'flex_slider_vars', array( 
		'animation' => get_option( 'tuned_animation' ) ? get_option( 'tuned_animation' ) : 'fade',
		'slideshow_speed' => get_option( 'tuned_slideshow_speed' ) ? get_option( 'tuned_slideshow_speed' ) : 7000,
		'animation_speed' => get_option( 'tuned_animation_speed') ? get_option( 'tuned_animation_speed' ) : 600
	) );
	
	//Add Infinite Scroll with Masonry for Infinite Scrolled Blog
	if( basename( get_page_template() ) == 'infinite-scrolled-blog.php' ) {
		wp_enqueue_script( 'isb', get_template_directory_uri() .'/js/isb.js' );
		wp_localize_script( 'isb', 'isb_vars', array( 
			'loader_img' => get_template_directory_uri() . '/js/vendor/infinite-scroll/ajax-loader.gif',
			'loader_text' => __( 'Loading...', 'tuned' ),
			'loading_finished_text' => __( 'All posts loaded.', 'tuned' )
		) );
	}
	

}
add_action( 'wp_enqueue_scripts', 'tuned_scripts' );


/* Register widgets 
-------------------------------------------------------------*/
function tuned_widgets_init() {

	register_sidebar( array( 
		'name'            => __( 'Main sidebar', 'tuned' ),
		'id'              => 'sidebar-1',
		'before_widget'   => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'    => '</aside>',
		'before_title'    => '<h3 class="widget-title">',
		'after_title'     => '</h3>'
	) );

    register_sidebar(array(
		'name'          => __('Tuned Page One', 'tuned'),
		'description' => __( 'Appears on the Tuned Page One Template.', 'tuned' ),
		'id'            => 'tuned-page-one-widget',
        'before_widget' => '<div>',
		'after_widget'  => '</ul>
						</div>',			
	));
	
	register_sidebar(array(
		'name'          => __('FPT - Hero Box', 'tuned'),
		'description' => __( 'Appears on the Front Page Template. This is a box for the Hero Widget', 'tuned' ),
		'id'            => 'front-page-template-hero'			
	));
	
	register_sidebar(array(
		'name'          => __('FPT - Carousel Box', 'tuned'),
		'description' => __( 'Appears on the Front Page Template. This is a box for the Carousel Widget', 'tuned' ),
		'id'            => 'front-page-template-carousel',
		'before_widget' => '<div>',
		'after_widget'  => '</ul>
						</div>',		
	));
	
	register_sidebar(array(
		'name'          => __('FPT - 1 Column Grid Box', 'tuned'),
		'description' => __( 'Appears on the Front Page Template. This is a 1 Column Grid Box for the Text Widget, and for the Category Posts Widget', 'tuned' ),
		'id'            => 'frontend-grid-1',
		'before_widget' => '<div id="grid1" class="grid">',
		'after_widget'  => '</div>',		
	));
	
	register_sidebar(array(
		'name'          => __('FPT - 3 Column Grid Box', 'tuned'),
		'description' => __( 'Appears on the Front Page Template. This is a 3 Column grid for the Category Posts Widget.', 'tuned' ),
		'id'            => 'frontend-grid-3',
		'before_widget' => '<div id="grid3" class="grid">',
		'after_widget'  => '<div style="clear: both"></div>
						</div>',		
	));
	
	register_sidebar(array(
		'name'          => __('FWT - Hero Box', 'tuned'),
		'description' => __( 'Appears on the Full Width Template. This is a box for the Hero Widget', 'tuned' ),
		'id'            => 'full-width-template-hero'				
	));
	
	register_sidebar(array(
		'name'          => __('FWT - Carousel Box', 'tuned'),
		'description' => __( 'Appears on the Full Width Template. This is a box for the Carousel Widget', 'tuned' ),
		'id'            => 'full-width-template-carousel',
		'before_widget' => '<div>',
		'after_widget'  => '</ul>
						</div>',		
	));
	
	register_sidebar(array(
		'name'          => __('ISBT - Hero Box', 'tuned'),
		'description' => __( 'Appears on the Infinite Scrolled Blog Template. This is a box for the Hero Widget', 'tuned' ),
		'id'            => 'isb-template-hero'		
	));
	
	register_sidebar(array(
		'name'          => __('ISBT - Carousel Box', 'tuned'),
		'description' => __( 'Appears on the Infinite Scrolled Blog Template. This is a box for the Carousel Widget', 'tuned' ),
		'id'            => 'isb-template-carousel',
		'before_widget' => '<div>',
		'after_widget'  => '</ul>
						</div>',		
	));
	
	register_sidebar(array(
		'name'          => __('Footer - 4 Column Grid', 'tuned'),
		'description' => __( 'Appears in the Footer Area. This is a 4 column grid.', 'tuned' ),
		'id'            => 'footer-4col-grid',
		'before_widget' => '<div class="footer-grid-4">',
		'after_widget'  => '</div>',		
	));
	
	register_widget('Tuned_Hero_Widget');
	register_widget('Tuned_Category_Widget');
	register_widget('Tuned_Carousel_Widget');
    register_widget('Tuned_Container_Start_Widget');
    register_widget('Tuned_Container_End_Widget');
    register_widget('Tuned_H1_Widget');
    register_widget('Tuned_H2_Widget');
    register_widget('Tuned_H3_Widget');    
    register_widget('Tuned_Two_Column_Widget');
    register_widget('Tuned_Three_Column_Widget');
    register_widget('Tuned_Hero_New_Widget');
    register_widget('Tuned_Slider_Widget');
    register_widget('Tuned_Image_Widget');
    register_widget('Tuned_CTA_Widget');

}
add_action( 'widgets_init', 'tuned_widgets_init' );
require_once( 'inc/widgets.php' );


/* Entry meta author
------------------------------------------------------------*/
if( !function_exists( 'tuned_entry_meta_author' ) ) {

	function tuned_entry_meta_author() {
					
		$date          = esc_attr( get_the_date() );
		$time          = esc_attr( get_the_time( 'c' ) );
		$author        = esc_attr( get_the_author() );
		$link_to_author_posts  = esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) );
	
		?>
		<time class="entry-date" datetime="<?php echo $time; ?>"><a href="<?php echo esc_url( get_permalink() ); ?>" rel="bookmark"><?php echo $date; ?></a></time>
		<span class="author vcard"> - <a href="<?php echo $link_to_author_posts; ?>"><?php echo __( 'By', 'tuned' ) . ' ' . $author; ?></a></span><br />		
		<?php
	}
	
}

/* Entry meta categories, tags
------------------------------------------------------------*/
if( !function_exists( 'tuned_entry_meta_ct' ) ) {

	function tuned_entry_meta_ct() {
			
		$category_list = get_the_category_list( __( ', ', 'tuned' ) );
		$tag_list      = get_the_tag_list( __( 'Tags', 'tuned' ) . ': ' , __( ', ', 'tuned' ) );		
	
		?>		
		<span class="category-list"><?php echo __( 'Categories', 'tuned' ) . ': ' . $category_list; ?></span>
		<span class="tag-list"><?php echo $tag_list; ?></span>
		<?php
	}
	
}

