<?php


if( ! function_exists( 'tuned_register' ) ) {

   function tuned_register( $wp_customize ) {

        $wp_customize->add_section( 'tuned_slider_settings' , array(
            'title'      => __( 'Slider settings', 'tuned' ),
            'priority'   => 199,
        ) );
        $wp_customize->add_section( 'tuned_hero_settings' , array(
            'title'      => __( 'Hero settings', 'tuned' ),
            'priority'   => 200,
        ) );

        $wp_customize->add_setting( 'tuned_animation' , array(
            'default'     => 'fade',
            'type'        => 'option',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'tuned_sanitize_select'        
        ) ); 

        $wp_customize->add_setting( 'tuned_slideshow_speed' , array(
            'default'     => 7000,
            'type'        => 'option',
            'capability'  => 'edit_theme_options', 
            'sanitize_callback' => 'tuned_sanitize_num'           
        ) );   

        $wp_customize->add_setting( 'tuned_animation_speed' , array(
            'default'     => 600,
            'type'        => 'option',
            'capability'  => 'edit_theme_options', 
            'sanitize_callback' => 'tuned_sanitize_num'          
        ) );

        $wp_customize->add_setting( 'tuned_full_width_slider' , array(
            'default'     => 'no',
            'type'        => 'option',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'tuned_sanitize_select'           
        ) );          

        $wp_customize->add_setting( 'tuned_full_width_hero' , array(
            'default'     => 'no',
            'type'        => 'option',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'tuned_sanitize_select'
        ) );      

        $wp_customize->add_control( 'tuned_animation', array(
	        'label'      => __( 'Animation', 'tuned' ),
	        'section'    => 'tuned_slider_settings',
	        'settings'   => 'tuned_animation',
            'type'       => 'select',            
            'choices'    => array(
                'fade' => __( 'fade', 'tuned' ),
                'slide' => __( 'slide', 'tuned' )               
                ),
        ) );        

        $wp_customize->add_control( 'tuned_slideshow_speed', array(
	        'label'        => __( 'Slideshow Speed', 'tuned' ),
	        'section'    => 'tuned_slider_settings',
	        'settings'   => 'tuned_slideshow_speed'            
        ) );

        $wp_customize->add_control( 'tuned_animation_speed', array(
	        'label'        => __( 'Animation Speed', 'tuned' ),
	        'section'    => 'tuned_slider_settings',
	        'settings'   => 'tuned_animation_speed'            
        ) );

        $wp_customize->add_control( 'tuned_full_width_slider', array(
	        'label'      => __( 'Full width Slider on the Front Page Template', 'tuned' ),
	        'section'    => 'tuned_slider_settings',
	        'settings'   => 'tuned_full_width_slider',
            'type'       => 'select',            
            'choices'    => array(
                'no' => __( 'No', 'tuned' ),
                'yes' => __( 'Yes', 'tuned' )               
                ),
        ) );

        $wp_customize->add_control( 'tuned_full_width_hero', array(
	        'label'        => __( 'Full width Hero on the Front Page Template', 'tuned' ),
	        'section'    => 'tuned_hero_settings',
	        'settings'   => 'tuned_full_width_hero',
            'type'       => 'select',            
            'choices'    => array(
                'no' => __( 'No', 'tuned' ),
                'yes' => __( 'Yes', 'tuned' )               
                ),
        ) );        

    }

}

function tuned_sanitize_select( $input, $setting ) {

    // Ensure input is a slug.
	$input = sanitize_key( $input );

    $choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

function tuned_sanitize_num( $number ) {

	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );

	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );

}

add_action( 'customize_register', 'tuned_register' );
