<?php

//Hero Widget
class Tuned_Hero_Widget extends WP_Widget {


    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_hero_widget',
            'description' => __( 'This widget displays the Hero Unit. You can use it in Hero boxes.', 'tuned' ),
        );
        parent::__construct( 'tuned_hero_widget', __( 'Hero Widget', 'tuned' ), $widget_ops );
    }
	
	function form($instance) {
		$instance = wp_parse_args( (array) $instance, array( 'hero-heading' => '', 'hero-tagline' => '', 'hero-button' => '', 'hero-button-link' => '' ) );
		$hero_heading = $instance['hero-heading'];
		$hero_tagline = $instance['hero-tagline'];
		$hero_button = $instance['hero-button'];
		$hero_button_link = $instance['hero-button-link'];
	?>	
		<p><label for="<?php echo $this->get_field_id('hero-heading'); ?>"><?php _e('Heading', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('hero-heading'); ?>" name="<?php echo $this->get_field_name('hero-heading'); ?>" 
		value="<?php echo esc_attr($hero_heading); ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('hero-tagline'); ?>"><?php _e('Tagline', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('hero-tagline'); ?>" name="<?php echo $this->get_field_name('hero-tagline'); ?>" 
		value="<?php echo esc_attr($hero_tagline); ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('hero-button'); ?>"><?php _e('Button', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('hero-button'); ?>" name="<?php echo $this->get_field_name('hero-button'); ?>" 
		value="<?php echo esc_attr($hero_button); ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('hero-button-link'); ?>"><?php _e('Link', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('hero-button-link'); ?>" name="<?php echo $this->get_field_name('hero-button-link'); ?>" 
		value="<?php echo esc_attr($hero_button_link); ?>" /></label></p>
		
	<?php
	}
	
	function update($new_instance, $old_instance) {
		
		$instance['hero-heading']      = ( ! empty( $new_instance['hero-heading'] ) ) ? strip_tags( $new_instance['hero-heading'] ) : '';
        $instance['hero-tagline']      = ( ! empty( $new_instance['hero-tagline'] ) ) ? strip_tags( $new_instance['hero-tagline'] ) : '';
        $instance['hero-button']       = ( ! empty( $new_instance['hero-button'] ) ) ? strip_tags( $new_instance['hero-button'] ) : '';
        $instance['hero-button-link']  = ( ! empty( $new_instance['hero-button-link'] ) ) ? strip_tags( $new_instance['hero-button-link'] ) : '';
      
		return $instance;

	}
	
	function widget($args, $instance) {
		extract($args, EXTR_SKIP);	
		
		echo $before_widget;
		
		$hero_heading = empty($instance['hero-heading']) ? 'Heading' : $instance['hero-heading'];
		$hero_tagline = empty($instance['hero-tagline']) ? 'Tagline' : $instance['hero-tagline'];
		$hero_button = $instance['hero-button'];
		$hero_button_link = $instance['hero-button-link'];
		?>
		
		<div class="hero-unit">
			<h1><?php echo $hero_heading; ?></h1>
			<p><?php echo $hero_tagline; ?></p>
			<?php if( !empty($hero_button) ) : ?>
			<a href="<?php echo esc_url( $hero_button_link ); ?>" class="btn-hero">
					<?php echo $hero_button; ?>			
			</a>
			<?php endif; ?>
		</div>
		
		<?php
		echo $after_widget;
	}
}


//Category Widget
class Tuned_Category_Widget extends WP_Widget {		
	

    public function __construct() {

        $widget_ops = array( 
            'classname' => 'tuned_category_widget',
            'description' => __( 'This widget displays posts from a category. You can use it in the One Column and the 3 Column Grid boxes.', 'tuned' ),
        );
        parent::__construct( 'tuned_category_widget', __( 'Category Posts Widget', 'tuned' ), $widget_ops );

    }
	
	function form($instance) {
		$instance = wp_parse_args( (array) $instance, array( 'category-slug' => '' ) );
		$category_slug = $instance['category-slug'];		
	?>	
		<p><?php _e( 'Usage: Add Posts with featured image to a Category, then add the Slug of Category to this Widget. If you want to display post featured image ONLY IN THE WIDGET, rename your image to _icon(eg. yourimage_icon.png)', 'tuned' ); ?></p>
		<p><label for="<?php echo $this->get_field_id('category-slug'); ?>"><?php _e('Slug of the Category', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('category-slug'); ?>" name="<?php echo $this->get_field_name('category-slug'); ?>" 
		value="<?php echo esc_attr($category_slug); ?>" /></label></p>				
		
	<?php
	}
	
	function update($new_instance, $old_instance) {

        $instance['category-slug'] = ( ! empty( $new_instance['category-slug'] ) ) ? strip_tags( $new_instance['category-slug'] ) : '';
        	
		return $instance;
	}
	
	function widget($args, $instance) {
	
		global $more;		
		extract($args, EXTR_SKIP);				
		
		echo $before_widget;
		
		$category_slug = empty($instance['category-slug']) ? 'Heading' : $instance['category-slug'];
		$category_by_slug = new WP_Query( array('category_name' => $category_slug, 'posts_per_page' => -1, 'orderby' => 'post_date', 'order' => 'ASC') );
		?>
				
			<?php while( $category_by_slug->have_posts() ) : $category_by_slug->the_post(); ?>
				<div class="category-posts">
				<?php $more = 0; ?>	
				<h1><?php the_title(); ?></h1>				
				<?php the_post_thumbnail(); ?>
				<?php the_content( __( 'Read more', 'tuned' ) ); ?>
				<?php edit_post_link( __( 'Edit', 'tuned' ), '<span class="edit-link">', '</span>' ); ?>
				<div style="clear: both"></div>
				</div>
			<?php endwhile; ?>
				
		<?php
		echo $after_widget;
	}
}


//Carousel Widget
class Tuned_Carousel_Widget extends WP_Widget {


    public function __construct() {

        $widget_ops = array( 
            'classname' => 'tuned_carousel_widget',
            'description' => __( 'Carousel widget displays posts with featured images from a category.(Image slider with text.) You can use it in Carousel boxes.', 'tuned' ),
        );
        parent::__construct( 'tuned_carousel_widget', __( 'Carousel Widget', 'tuned' ), $widget_ops );

    }
	
	function form($instance) {
		$instance = wp_parse_args( (array) $instance, array( 'category-slug' => '' ) );
		$category_slug = $instance['category-slug'];		
	?>	
	
		<p><?php _e( 'Usage: Add Posts with featured image to a Category, then add the Slug of Category to this Widget. If you want to display post\'s featured image ONLY IN THE WIDGET, rename your image to _icon(eg. yourimage_icon.png)', 'tuned' ); ?></p>
		<p><label for="<?php echo $this->get_field_id('category-slug'); ?>"><?php _e('Slug of the Category', 'tuned') ?>: <input class="widefat" 
		id="<?php echo $this->get_field_id('category-slug'); ?>" name="<?php echo $this->get_field_name('category-slug'); ?>" 
		value="<?php echo esc_attr($category_slug); ?>" /></label></p>				
		
	<?php
	}
	
	function update($new_instance, $old_instance) {
		
        $instance['category-slug'] = ( ! empty( $new_instance['category-slug'] ) ) ? strip_tags( $new_instance['category-slug'] ) : '';	
        	
		return $instance;
	}
	
	function widget($args, $instance) {
		extract($args, EXTR_SKIP);				
		global $more;
        $before_widget = str_replace('<div>', '<div class="flexslider"><ul class="slides">', $before_widget);
		echo $before_widget;        
		
		$category_slug = empty($instance['category-slug']) ? 'Heading' : $instance['category-slug'];
		$category_by_slug = new WP_Query( array('category_name' => $category_slug, 'posts_per_page' => -1, 'orderby' => 'post_date', 'order' => 'ASC') );
		?>	
		<?php if( $category_by_slug->have_posts() ) : ?>
			<?php while( $category_by_slug->have_posts() ) : $category_by_slug->the_post(); ?>
				<li>
				<?php the_post_thumbnail(); ?>
				<div class="flex-caption">
                    <div>
					    <?php $more = 0; ?>					
					    <h1><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h1>
					    <?php the_content( __( 'Read more', 'tuned' ) ); ?>
                    </div>
				</div>
				</li>
			<?php endwhile; ?>
		<?php endif ?>
		
		<?php
		echo $after_widget;
	}
}


// Tuned Container Start Widget
class Tuned_Container_Start_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_container_start',
            'description' => __( 'This is the Container Start widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_container_start', __( 'Tuned Container START', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) { ?>
        <div class="tuned-row">
    <?php }

}


// Tuned Container End Widget
class Tuned_Container_End_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_container_end',
            'description' => __( 'This is the Container End widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_container_end', __( 'Tuned Container END', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) { ?>
        </div>
    <?php }

}


// Tuned H1 Widget
class Tuned_H1_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_h1',
            'description' => __( 'This is the H1 widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_h1', __( 'Tuned H1', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $text         = empty($instance['text']) ?  __( 'This is the Heading 1', 'tuned' ) : $instance['text']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];       
        
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';             
        echo '<h1 class="tuned-h1">' . esc_html( $text ) . '</h1>';
        echo '</div>';

    }

    public function form( $instance ) {

        $text         = ! empty( $instance['text'] ) ? $instance['text'] : __( 'This is the Heading 1', 'tuned' );
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( esc_attr( 'Text' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $text ); ?>" />        
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance                  = array();
        $instance['text']          = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['space_bottom']  = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}
    
// Tuned H2 Widget
class Tuned_H2_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_h2',
            'description' => __( 'This is the H2 widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_h2', __( 'Tuned H2', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $text         = empty($instance['text']) ?  __( 'This is the Heading 2', 'tuned' ) : $instance['text']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];       
        
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';             
        echo '<h2 class="tuned-h2">' . esc_html( $text ) . '</h2>';
        echo '</div>';

    }

    public function form( $instance ) {

        $text         = ! empty( $instance['text'] ) ? $instance['text'] : __( 'This is the Heading 2', 'tuned' );
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( esc_attr( 'Text' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $text ); ?>" />        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance                 = array();
        $instance['text']         = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}

// Tuned H3 Widget
class Tuned_H3_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_h3',
            'description' => __( 'This is the H3 widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_h3', __( 'Tuned H3', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $text         = empty($instance['text']) ?  __( 'This is the Heading 3', 'tuned' ) : $instance['text']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];       
        
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';             
        echo '<h3 class="tuned-h3">' . esc_html( $text ) . '</h3>';
        echo '</div>';
    }

    public function form( $instance ) {

        $text         = ! empty( $instance['text'] ) ? $instance['text'] : __( 'This is the Heading 3', 'tuned' );
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( esc_attr( 'Text' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $text ); ?>" />        
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();
        $instance['text'] = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}


// Tuned Two Column Widget
class Tuned_Two_Column_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_two_column',
            'description' => __( 'This is the Two Column widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_two_column', __( 'Tuned Two Column', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $heading      = empty($instance['heading']) ? __( 'This is the Heading', 'tuned' ) : $instance['heading'];  
        $heading2     = empty($instance['heading2']) ? __( 'This is the Heading 2', 'tuned' ) : $instance['heading2'];   
        $text         = empty($instance['text']) ? __( 'This is the Text', 'tuned' ) : $instance['text'];             
        $text2        = empty($instance['text2']) ? __( 'This is the Text 2', 'tuned' ) : $instance['text2']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];                
       
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';
        echo '<div class="grid-2-1">';
        echo '<h3 class="tuned-h3">' . esc_html( $heading ) . '</h3>';
        echo '<p>' . esc_html( $text ) . '</p>';
        echo '</div>';
        echo '<div class="grid-2-1">';
        echo '<h3 class="tuned-h3">' . esc_html( $heading2 ) . '</h3>';
        echo '<p>' . esc_html( $text2 ) . '</p>';
        echo '</div>';
        echo '</div>';
        
    }

    public function form( $instance ) {

        $heading      = ! empty( $instance['heading'] ) ? $instance['heading'] : __( 'This is the Heading', 'tuned' );
        $heading2     = ! empty( $instance['heading2'] ) ? $instance['heading2'] : __( 'This is the Heading 2', 'tuned' );
        $text         = ! empty( $instance['text'] ) ? $instance['text'] : __( 'This is the Text', 'tuned' );
        $text2        = ! empty( $instance['text2'] ) ? $instance['text2'] : __( 'This is the Text 2', 'tuned' );
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>"><?php _e( esc_attr( 'Heading' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( esc_attr( 'Text' ), 'tuned' ) ?>: </label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>"><?php echo esc_textarea( $text ); ?></textarea>        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>"><?php _e( esc_attr( 'Heading 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading2' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading2 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text2' ) ); ?>"><?php _e( esc_attr( 'Text 2' ), 'tuned' ) ?>: </label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text2' ) ); ?>"><?php echo esc_textarea( $text2 ); ?></textarea>        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();
        $instance['heading']      = ( ! empty( $new_instance['heading'] ) ) ? strip_tags( $new_instance['heading'] ) : '';
        $instance['heading2']     = ( ! empty( $new_instance['heading2'] ) ) ? strip_tags( $new_instance['heading2'] ) : '';
        $instance['text']         = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['text2']        = ( ! empty( $new_instance['text2'] ) ) ? strip_tags( $new_instance['text2'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}

// Tuned Three Column Widget
class Tuned_Three_Column_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_three_column',
            'description' => __( 'This is the Three Column widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_three_column', __( 'Tuned Three Column', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $heading      = empty($instance['heading']) ? __( 'This is the Heading', 'tuned' ) : $instance['heading'];  
        $heading2     = empty($instance['heading2']) ? __( 'This is the Heading 2', 'tuned' ) : $instance['heading2'];
        $heading3     = empty($instance['heading3']) ? __( 'This is the Heading 3', 'tuned' ) : $instance['heading3'];         
        $text         = empty($instance['text']) ? __( 'This is the Text', 'tuned' ) : $instance['text'];             
        $text2        = empty($instance['text2']) ? __( 'This is the Text 2', 'tuned' ) : $instance['text2']; 
        $text3        = empty($instance['text3']) ? __( 'This is the Text 3', 'tuned' ) : $instance['text3']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];                 
       
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';
        echo '<div class="grid-3-1">';
        echo '<h3 class="tuned-h3">' . esc_html( $heading ) . '</h3>';
        echo '<p>' . esc_html( $text ) . '</p>';
        echo '</div>';
        echo '<div class="grid-3-1">';
        echo '<h3 class="tuned-h3">' . esc_html( $heading2 ) . '</h3>';
        echo '<p>' . esc_html( $text2 ) . '</p>';
        echo '</div>';      
        echo '<div class="grid-3-1">';
        echo '<h3 class="tuned-h3">' . esc_html( $heading3 ) . '</h3>';
        echo '<p>' . esc_html( $text3 ) . '</p>';
        echo '</div>';
        echo '</div>';
        
    }

    public function form( $instance ) {

        $heading      = ! empty( $instance['heading'] ) ? $instance['heading'] : __( 'This is the Heading', 'tuned' );
        $heading2     = ! empty( $instance['heading2'] ) ? $instance['heading2'] : __( 'This is the Heading 2', 'tuned' );
        $heading3     = ! empty( $instance['heading3'] ) ? $instance['heading3'] : __( 'This is the Heading 3', 'tuned' );
        $text         = ! empty( $instance['text'] ) ? $instance['text'] : __( 'This is the Text', 'tuned' );
        $text2        = ! empty( $instance['text2'] ) ? $instance['text2'] : __( 'This is the Text 2', 'tuned' );
        $text3        = ! empty( $instance['text3'] ) ? $instance['text3'] : __( 'This is the Text 3', 'tuned' );
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>"><?php _e( esc_attr( 'Heading' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( esc_attr( 'Text' ), 'tuned' ) ?>: </label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>"><?php echo esc_textarea( $text ); ?></textarea>        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>"><?php _e( esc_attr( 'Heading 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading2' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading2 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text2' ) ); ?>"><?php _e( esc_attr( 'Text 2' ), 'tuned' ) ?>: </label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text2' ) ); ?>"><?php echo esc_textarea( $text2 ); ?></textarea>        
        </p>

        <label for="<?php echo esc_attr( $this->get_field_id( 'heading3' ) ); ?>"><?php _e( esc_attr( 'Heading 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading3' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading3 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'text3' ) ); ?>"><?php _e( esc_attr( 'Text 3' ), 'tuned' ) ?>: </label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text3' ) ); ?>"><?php echo esc_textarea( $text3 ); ?></textarea>        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();
        $instance['heading']      = ( ! empty( $new_instance['heading'] ) ) ? strip_tags( $new_instance['heading'] ) : '';
        $instance['heading2']     = ( ! empty( $new_instance['heading2'] ) ) ? strip_tags( $new_instance['heading2'] ) : '';
        $instance['heading3']     = ( ! empty( $new_instance['heading3'] ) ) ? strip_tags( $new_instance['heading3'] ) : '';
        $instance['text']         = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['text2']        = ( ! empty( $new_instance['text2'] ) ) ? strip_tags( $new_instance['text2'] ) : '';
        $instance['text3']        = ( ! empty( $new_instance['text3'] ) ) ? strip_tags( $new_instance['text3'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}

// Tuned Hero Widget
class Tuned_Hero_New_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname'   => 'tuned_hero',
            'description' => __( 'This is the Tuned Hero widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_hero', __( 'Tuned Hero', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $heading      = empty($instance['heading']) ? __( 'This is the Heading', 'tuned' ) : $instance['heading'];  
        $tagline      = empty($instance['tagline']) ? __( 'This is the Tagline', 'tuned' ) : $instance['tagline'];     
        $cta          = empty($instance['cta']) ? __( 'Call to action', 'tuned' ) : $instance['cta'];             
        $link         = empty($instance['link']) ? '#' : $instance['link']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];                 
       
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';
        echo '<div class="hero-unit">';
	    echo '<h1>' . esc_html( $heading ) . '</h1>';
		echo '<p>' . esc_html( $tagline ) . '</p>';
		echo '<a href="' . esc_url( $link ) . '" class="btn-hero">' . esc_html( $cta ) . '</a>';
		echo '</div>';
        echo '</div>';
        
}

    public function form( $instance ) {

        $heading      = ! empty( $instance['heading'] ) ? $instance['heading'] : __( 'This is the Heading', 'tuned' );
        $tagline      = ! empty( $instance['tagline'] ) ? $instance['tagline'] : __( 'This is the Tagline', 'tuned' );
        $cta          = ! empty( $instance['cta'] ) ? $instance['cta'] : __( 'Call to action', 'tuned' );
        $link         = ! empty( $instance['link'] ) ? $instance['link'] : '#';
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>"><?php _e( esc_attr( 'Heading' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'tagline' ) ); ?>"><?php _e( esc_attr( 'Tagline' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tagline' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tagline' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $tagline ); ?>" />        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>"><?php _e( esc_attr( 'Call to action' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cta' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $cta ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php _e( esc_attr( 'Link' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $link ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();
        $instance['heading']      = ( ! empty( $new_instance['heading'] ) ) ? strip_tags( $new_instance['heading'] ) : '';
        $instance['tagline']      = ( ! empty( $new_instance['tagline'] ) ) ? strip_tags( $new_instance['tagline'] ) : '';
        $instance['cta']          = ( ! empty( $new_instance['cta'] ) ) ? strip_tags( $new_instance['cta'] ) : '';
        $instance['link']         = ( ! empty( $new_instance['link'] ) ) ? strip_tags( $new_instance['link'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}

// Tuned Slider Widget
class Tuned_Slider_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname'   => 'tuned_slider',
            'description' => __( 'This is the Tuned Slider widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );

        parent::__construct( 'tuned_slider', __( 'Tuned Slider', 'tuned' ), $widget_ops );
        
        add_action('admin_enqueue_scripts', array($this, 'upload_scripts'));
    }

    public function upload_scripts() {

        wp_enqueue_script('media-upload');
        wp_enqueue_script('thickbox');
        wp_enqueue_script('tuned_slider', get_template_directory_uri() . '/js/upload_media.js', array('jquery'));

        wp_enqueue_style('thickbox');

        }

    public function widget( $args, $instance ) {

        $heading        = empty($instance['heading']) ? __( 'This is the Heading', 'tuned' ) : $instance['heading'];
        $tagline        = empty($instance['tagline']) ? __( 'This is the Tagline', 'tuned' ) : $instance['tagline']; 
        $imgsrc         = empty($instance['imgsrc']) ? get_template_directory_uri() . '/images/img1.png' : $instance['imgsrc'];
        $cta            = empty($instance['cta']) ? __( 'Call to action', 'tuned' ) : $instance['cta'];  
        $link           = empty($instance['link']) ? '#' : $instance['link'];

        $heading2       = empty($instance['heading2']) ? __( 'This is the Heading 2', 'tuned' ) : $instance['heading2']; 
        $tagline2       = empty($instance['tagline2']) ? __( 'This is the Tagline 2', 'tuned' ) : $instance['tagline2'];
        $imgsrc2        = empty($instance['imgsrc2']) ? '' : $instance['imgsrc2'];
        $cta2           = empty($instance['cta2']) ? __( 'Call to action 2', 'tuned' ) : $instance['cta2'];
        $link2          = empty($instance['link2']) ? '#' : $instance['link2'];   
   
        $heading3       = empty($instance['heading3']) ? __( 'This is the Heading 3', 'tuned' ) : $instance['heading3'];    
        $tagline3       = empty($instance['tagline3']) ? __( 'This is the Tagline 3', 'tuned' ) : $instance['tagline3'];      
        $imgsrc3        = empty($instance['imgsrc3']) ? '' : $instance['imgsrc3'];                 
        $cta3           = empty($instance['cta3']) ? __( 'Call to action 3', 'tuned' ) : $instance['cta3'];
        $link3          = empty($instance['link3']) ? '#' : $instance['link3']; 

        $space_bottom   = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];                 
       
        echo '<div class="row" style="margin-bottom: ' . esc_attr( $space_bottom ) . '">';
        echo '<div class="flexslider">';
        echo '<ul class="slides">';

        echo '<li>';        
        echo '<img src="'. esc_url( $imgsrc ) .'" />';	
        echo '<div class="flex-caption">';
        echo '<h1><a href="'. esc_url( $link ) .'" title="">'. esc_html( $heading ) .'</a></h1>';	
        echo '<p>'. esc_html( $tagline ) .'</p>';
        echo '<p><a class="more-link" href="'. esc_url( $link ) .'">'. esc_html( $cta ) .'</a></p>';
        echo '</div>';	       
        echo '</li>';

        if( ! empty($instance['imgsrc2']) ) :
        echo '<li>';        
        echo '<img src="'. esc_url( $imgsrc2 ) .'" />';	
        echo '<div class="flex-caption">';
        echo '<h1><a href="'. esc_url( $link2 ) .'" title="">'. esc_html( $heading2 ) .'</a></h1>';	
        echo '<p>'. esc_html( $tagline2 ) .'</p>';
        echo '<p><a class="more-link" href="'. esc_url( $link2 ) .'">'. esc_attr( $cta2 ) .'</a></p>';
        echo '</div>';		
        echo '</li>';
        endif;

        if( ! empty($instance['imgsrc3']) ) :
        echo '<li>';        
        echo '<img src="'. esc_url( $imgsrc3 ) .'" />';	
        echo '<div class="flex-caption">';       
        echo '<h1><a href="'. esc_url( $link3 ) .'" title="">'. esc_html( $heading3 ) .'</a></h1>';	
        echo '<p>'. esc_html( $tagline3 ) .'</p>';
        echo '<p><a class="more-link" href="'. esc_url( $link3 ) .'">'. esc_html( $cta3 ) .'</a></p>';
        echo '</div>';	       
        echo '</li>';
        endif;
			
        echo '</ul>';
        echo '</div>';	
        echo '</div>';
        
    }

    public function form( $instance ) {

        $imgsrc       = ! empty( $instance['imgsrc'] ) ? $instance['imgsrc'] : '';
        $heading      = ! empty( $instance['heading'] ) ? $instance['heading'] : __( 'This is the Heading', 'tuned' );
        $tagline      = ! empty( $instance['tagline'] ) ? $instance['tagline'] : __( 'This is the Tagline', 'tuned' );
        $cta          = ! empty( $instance['cta'] ) ? $instance['cta'] : __( 'Call to action', 'tuned' );
        $link         = ! empty( $instance['link'] ) ? $instance['link'] : '#';

        $imgsrc2       = ! empty( $instance['imgsrc2'] ) ? $instance['imgsrc2'] : '';
        $heading2      = ! empty( $instance['heading2'] ) ? $instance['heading2'] : __( 'This is the Heading 2', 'tuned' );
        $tagline2      = ! empty( $instance['tagline2'] ) ? $instance['tagline2'] : __( 'This is the Tagline2', 'tuned' );
        $cta2          = ! empty( $instance['cta2'] ) ? $instance['cta2'] : __( 'Call to action 2', 'tuned' );
        $link2         = ! empty( $instance['link2'] ) ? $instance['link2'] : '#';

        $imgsrc3       = ! empty( $instance['imgsrc3'] ) ? $instance['imgsrc3'] : '';
        $heading3      = ! empty( $instance['heading3'] ) ? $instance['heading3'] : __( 'This is the Heading 3', 'tuned' );
        $tagline3      = ! empty( $instance['tagline3'] ) ? $instance['tagline3'] : __( 'This is the Tagline3', 'tuned' );
        $cta3          = ! empty( $instance['cta3'] ) ? $instance['cta3'] : __( 'Call to action 3', 'tuned' );
        $link3         = ! empty( $instance['link3'] ) ? $instance['link3'] : '#';

        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" /> 
        </p>       
        

        <p>
        <h4><?php echo __( 'Slide 1', 'tuned' ); ?></h4>
        <label for="<?php echo esc_attr( $this->get_field_id( 'imgsrc' ) ); ?>"><?php _e( esc_attr( 'Image' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'imgsrc' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'imgsrc' ) ); ?>" 
            type="text" value="<?php echo esc_url( $imgsrc ); ?>" />      
            <input class="upload_image_button button button-primary" type="button" value="<?php echo __( 'Upload Image', 'tuned' ); ?>" />  
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>"><?php _e( esc_attr( 'Heading' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'tagline' ) ); ?>"><?php _e( esc_attr( 'Tagline' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tagline' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tagline' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $tagline ); ?>" />        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>"><?php _e( esc_attr( 'Call to action' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cta' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $cta ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php _e( esc_attr( 'Link' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" 
            type="text" value="<?php echo esc_url( $link ); ?>" />        
        </p>


        <p>
        <h4><?php echo __( 'Slide 2', 'tuned' ); ?></h4>
        <label for="<?php echo esc_attr( $this->get_field_id( 'imgsrc2' ) ); ?>"><?php _e( esc_attr( 'Image 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'imgsrc2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'imgsrc2' ) ); ?>" 
            type="text" value="<?php echo esc_url( $imgsrc2 ); ?>" />      
            <input class="upload_image_button button button-primary" type="button" value="<?php echo __( 'Upload Image', 'tuned' ); ?>" />  
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>"><?php _e( esc_attr( 'Heading 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading2' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading2 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'tagline2' ) ); ?>"><?php _e( esc_attr( 'Tagline 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tagline2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tagline2' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $tagline2 ); ?>" />        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'cta2' ) ); ?>"><?php _e( esc_attr( 'Call to action 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'cta2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cta2' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $cta2 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'link2' ) ); ?>"><?php _e( esc_attr( 'Link 2' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link2' ) ); ?>" 
            type="text" value="<?php echo esc_url( $link2 ); ?>" />        
        </p>


        <p>
        <h4><?php echo __( 'Slide 3', 'tuned' ); ?></h4>
        <label for="<?php echo esc_attr( $this->get_field_id( 'imgsrc3' ) ); ?>"><?php _e( esc_attr( 'Image 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'imgsrc3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'imgsrc3' ) ); ?>" 
            type="text" value="<?php echo esc_url( $imgsrc3 ); ?>" />      
            <input class="upload_image_button button button-primary" type="button" value="<?php echo __( 'Upload Image', 'tuned' ); ?>" />  
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'heading3' ) ); ?>"><?php _e( esc_attr( 'Heading 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'heading3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'heading3' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $heading3 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'tagline3' ) ); ?>"><?php _e( esc_attr( 'Tagline 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tagline3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tagline3' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $tagline3 ); ?>" />        
        </p>

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'cta3' ) ); ?>"><?php _e( esc_attr( 'Call to action 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'cta3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cta3' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $cta3 ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'link3' ) ); ?>"><?php _e( esc_attr( 'Link 3' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link3' ) ); ?>" 
            type="text" value="<?php echo esc_url( $link3 ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();

        $instance['imgsrc']       = ( ! empty( $new_instance['imgsrc'] ) ) ? strip_tags( $new_instance['imgsrc'] ) : '';
        $instance['heading']      = ( ! empty( $new_instance['heading'] ) ) ? strip_tags( $new_instance['heading'] ) : '';
        $instance['tagline']      = ( ! empty( $new_instance['tagline'] ) ) ? strip_tags( $new_instance['tagline'] ) : '';
        $instance['cta']          = ( ! empty( $new_instance['cta'] ) ) ? strip_tags( $new_instance['cta'] ) : '';
        $instance['link']         = ( ! empty( $new_instance['link'] ) ) ? strip_tags( $new_instance['link'] ) : '';

        $instance['imgsrc2']      = ( ! empty( $new_instance['imgsrc2'] ) ) ? strip_tags( $new_instance['imgsrc2'] ) : '';
        $instance['heading2']     = ( ! empty( $new_instance['heading2'] ) ) ? strip_tags( $new_instance['heading2'] ) : '';
        $instance['tagline2']     = ( ! empty( $new_instance['tagline2'] ) ) ? strip_tags( $new_instance['tagline2'] ) : '';
        $instance['cta2']         = ( ! empty( $new_instance['cta2'] ) ) ? strip_tags( $new_instance['cta2'] ) : '';
        $instance['link2']        = ( ! empty( $new_instance['link2'] ) ) ? strip_tags( $new_instance['link2'] ) : '';

        $instance['imgsrc3']      = ( ! empty( $new_instance['imgsrc3'] ) ) ? strip_tags( $new_instance['imgsrc3'] ) : '';
        $instance['heading3']     = ( ! empty( $new_instance['heading3'] ) ) ? strip_tags( $new_instance['heading3'] ) : '';
        $instance['tagline3']     = ( ! empty( $new_instance['tagline3'] ) ) ? strip_tags( $new_instance['tagline3'] ) : '';
        $instance['cta3']         = ( ! empty( $new_instance['cta3'] ) ) ? strip_tags( $new_instance['cta3'] ) : '';
        $instance['link3']        = ( ! empty( $new_instance['link3'] ) ) ? strip_tags( $new_instance['link3'] ) : '';

        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}


// Tuned Image Widget
class Tuned_Image_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname' => 'tuned_image',
            'description' => __( 'This is the Image widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );

        parent::__construct( 'tuned_image', __( 'Tuned Image', 'tuned' ), $widget_ops );

        add_action('admin_enqueue_scripts', array($this, 'upload_scripts'));

    }


    public function upload_scripts() {

        wp_enqueue_script('media-upload');
        wp_enqueue_script('thickbox');
        wp_enqueue_script('tuned_slider', get_template_directory_uri() . '/js/upload_media.js', array('jquery'));

        wp_enqueue_style('thickbox');

        }

    public function widget( $args, $instance ) {

        $imgsrc         = empty($instance['imgsrc']) ?  '' : $instance['imgsrc']; 
        $space_bottom   = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];       
        
        echo '<div class="row" style="text-align: center; margin-bottom: ' . esc_attr( $space_bottom ) . '">';             
        echo '<img src="'. esc_url( $imgsrc ) .'" />';
        echo '</div>';
    }

    public function form( $instance ) {

        $imgsrc         = ! empty( $instance['imgsrc'] ) ? $instance['imgsrc'] : '';
        $space_bottom   = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>        
        <label for="<?php echo esc_attr( $this->get_field_id( 'imgsrc' ) ); ?>"><?php _e( esc_attr( 'Image' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'imgsrc' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'imgsrc' ) ); ?>" 
            type="text" value="<?php echo esc_url( $imgsrc ); ?>" />      
            <input class="upload_image_button button button-primary" type="button" value="<?php echo __( 'Upload Image', 'tuned' ); ?>" />  
        </p>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();
        $instance['imgsrc'] = ( ! empty( $new_instance['imgsrc'] ) ) ? strip_tags( $new_instance['imgsrc'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}


// Tuned Call to Action Button Widget
class Tuned_CTA_Widget extends WP_Widget {

    public function __construct() {
        $widget_ops = array( 
            'classname'   => 'tuned_cta',
            'description' => __( 'This is the Tuned Call to Action Button widget. You can use it in the Tuned One Page widget box.', 'tuned' ),
        );
        parent::__construct( 'tuned_cta', __( 'Tuned CTA', 'tuned' ), $widget_ops );
    }

    public function widget( $args, $instance ) {
          
        $cta          = empty($instance['cta']) ? __( 'Call to action', 'tuned' ) : $instance['cta'];             
        $link         = empty($instance['link']) ? '#' : $instance['link']; 
        $space_bottom = empty($instance['space_bottom']) ? '20px' : $instance['space_bottom'];                 
       
        echo '<div class="row" style="text-align: center; margin-bottom: ' . esc_attr( $space_bottom ) . '">';        
		echo '<a href="' . esc_url( $link ) . '" class="btn-cta">' . esc_html( $cta ) . '</a>';		
        echo '</div>';
        
}

    public function form( $instance ) {
       
        $cta          = ! empty( $instance['cta'] ) ? $instance['cta'] : __( 'Call to action', 'tuned' );
        $link         = ! empty( $instance['link'] ) ? $instance['link'] : '#';
        $space_bottom = ! empty( $instance['space_bottom'] ) ? $instance['space_bottom'] : '20px'; ?>

        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>"><?php _e( esc_attr( 'Space bottom' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'space_bottom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'space_bottom' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $space_bottom ); ?>" />        
        </p>        

         <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>"><?php _e( esc_attr( 'Call to action' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'cta' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cta' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $cta ); ?>" />        
        </p>
    
        <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php _e( esc_attr( 'Link' ), 'tuned' ) ?>: </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" 
            type="text" value="<?php echo esc_attr( $link ); ?>" />        
        </p>

   <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();        
        $instance['cta']          = ( ! empty( $new_instance['cta'] ) ) ? strip_tags( $new_instance['cta'] ) : '';
        $instance['link']         = ( ! empty( $new_instance['link'] ) ) ? strip_tags( $new_instance['link'] ) : '';
        $instance['space_bottom'] = ( ! empty( $new_instance['space_bottom'] ) ) ? strip_tags( $new_instance['space_bottom'] ) : '';

        return $instance;

    }

}
